#
# $Id: PloneContactItem.py 22138 2005-07-20 10:46:41Z kilobug $
#

"""PloneContactItem class"""

# Standard Python imports
import string, os

# Zope core imports
from AccessControl import ClassSecurityInfo
from Products.Archetypes.BaseContent import BaseContent
from Products.Archetypes.public import *

from Products.Archetypes.ArchetypeTool import registerType
from AccessControl.SecurityManagement import newSecurityManager
from Products.Archetypes.utils import DisplayList

# CMF/Plone imports
from Products.CMFCore.CMFCorePermissions import View, ListFolderContents, ModifyPortalContent


class PloneContactItem(BaseContent):
    """PloneContactItem class
    """

    ########################################
    ## Registration info for portal_types ##
    ########################################

    meta_type = portal_type = archetype_name = 'Plone Contact Item'

    content_icon = 'PloneContactItem.png'

    description = 'Hold one contact form'

    implicitly_addable = 0

    actions = (
            {'id': 'view',
             'name': 'View',
             'action': 'string:${object_url}/contactitem_view',
             'permissions': (View,)},
            )

    schema=BaseContent.schema + Schema((

        StringField('name',
                    default='',
                    searchable=True,
                    required = True,
                    widget=StringWidget(label='Fullname',
                                        description='The full name of the sender',
                                        label_msgid='label_fullname',
                                        description_msgid='help_fullname',
                                        i18n_domain="plonecontactfolder")
                  ),

        StringField('person_title',
                    default='',
                    searchable=True,
                    required = True,
                    vocabulary="getPersonTitles",
                    widget=SelectionWidget(label='Title',
                                           description='The title of the sender',
                                           label_msgid='label_person_title',
                                           description_msgid='help_person_title',
                                           i18n_domain="plonecontactfolder")
                  ),

        StringField('mailfrom',
                    default='',
                    searchable=True,
                    required = True,
                    validators=('isEmail',),
                    widget=StringWidget(label='From',
                                        description='E-mail address of the sender',
                                        label_msgid='label_from',
                                        description_msgid='help_from',
                                        i18n_domain="plonecontactfolder")
                  ),

        StringField('mailconfirm',
                    default='',
                    searchable=True,
                    required = True,
                    validators=('isEmail',),
                    widget=StringWidget(label='Confirm from',
                                        description='Confirm e-mail address of the sender',
                                        label_msgid='label_confirm_from',
                                        description_msgid='help_confirm_from',
                                        i18n_domain="plonecontactfolder")
                  ),

        StringField('company',
                    default='',
                    searchable=True,
                    widget=StringWidget(label='Company',
                                        description='The company of the sender',
                                        label_msgid='label_company',
                                        description_msgid='help_company',
                                        i18n_domain="plonecontactfolder")
                  ),

        StringField('category',
                    default='',
                    searchable=True,
                    required = True,
                    vocabulary='getCategoryList',
                    widget=SelectionWidget(label='Category',
                                           description='Category of the message',
                                           label_msgid='label_category',
                                           description_msgid='help_category',
                                           i18n_domain="plonecontactfolder")
                    ),
        

        StringField('message',
                    default='',
                    required = True,
                    searchable=True,
                    widget=TextAreaWidget(label='Message',
                                          description='The message itself',
                                          label_msgid='label_message',
                                          description_msgid='help_message',
                                          i18n_domain="plonecontactfolder")
                    ),
       
    )) 

    ###########################
    ## Basic class behaviour ##
    ###########################

    # Standard security settings
    security = ClassSecurityInfo()
    security.declareObjectProtected(View)

    # Init method
    def __init__(self, id, title=''):
        """__init__(self, id, title='')"""
        BaseContent.__init__(self, id, title = title)

    security.declarePublic('getPersonTitles')
    def getPersonTitles(self):
        """Get the list of titles"""
        folder = self.getParentNode()
        lst = folder.getPersonTitles()
        return DisplayList(lst)

    security.declarePublic('getCategoryList')
    def getCategoryList(self):
        """Get the list of category"""
        folder = self.getParentNode()
        lst = folder.getCategoryList()
        return DisplayList(lst)

    security.declareProtected(View, 'getMonth')
    def getMonth(self):
        """Get the month"""
        crdate = self.created()
        return crdate.strftime("%Y-%m")

    security.declarePublic('send')
    def send(self):
        """Send the message"""
        if not getattr(self, '_sent', False):
            folder = self.getParentNode()
            root = self.portal_url.getPortalObject()
            mh = folder.MailHost
            category = folder.categories[self.category]
            template = folder.template
            values = {
                "title": self.title,
                "subject": self.title,
                "from": self.mailfrom,
                "name": self.name,
                "fullname": self.name,
                "company": self.company,
                "person_title": self.person_title,
                "message": self.message,
                "category": category['name'],
                "portal_name": root.title_or_id(),
                "portal_url": root.absolute_url(),
                "message_url": self.absolute_url(),
                }
            charset = self.portal_properties.site_properties.default_charset
            for k,v in values.items():
                if (not isinstance(v, unicode)):
                    values[k] = unicode(v, charset)
            body = (unicode(template, charset) % values).encode(charset)
            body = "Content-Type: text/plain; charset=%s\r\n" % charset + body
            mh.send(body, mto = category["mails"],
                    mfrom = root.getProperty("email_from_address"))
            self._sent = True
        
# Class instanciation
registerType(PloneContactItem)

